multidim.models — GDA Toolbox v1.0 Manual

# multidim.models

This module contains classifiers based on the SciKitLearn framework.

> - `CDER`
> - `GaussianMixtureClassifier`

We use these for modelling marked-point processes and labelled pointclouds.

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Classes

`CDER`([stop_level]) | The CDER (Cover-Tree Differencing for Entropy Reduction) algorithm for supervised machine-learning of labelled cloud collections.
`GaussianMixtureClassifier`([stop_level]) | A scikit-learn classification estimator, for any sort of Gaussian mixture model.

### Table of Contents

- multidim.models
  - Copyright

#### Previous topic

multidim.fast_algorithms

#### Next topic

multidim.models.CDER